#
# spec file for package python-rethinkdb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-rethinkdb
Version:        2.4.10.post1
Release:        1.7
Summary:        Python driver library for the RethinkDB database server
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/RethinkDB/rethinkdb-python
Source:         https://github.com/rethinkdb/rethinkdb-python/archive/v%{version}.tar.gz#/rethinkdb-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/rethinkdb/rethinkdb/next/src/rdb_protocol/ql2.proto
BuildRequires:  %{python_module looseversion >= 1.3.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-looseversion >= 1.3.0
Requires:       python-six
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module six}
# /SECTION
%python_subpackages

%description
Python driver library for the RethinkDB database server.

%prep
%setup -q -n rethinkdb-python-%{version}

# Excerpt from Makefile, needed because this is using the GitHub archive instead of PyPI sdist
cp %{SOURCE1} rethinkdb/ql2.proto
python3 scripts/convert_protofile.py -l python -i rethinkdb/ql2.proto -o rethinkdb/ql2_pb2.py

# These require a rethinkdb instance running
rm -r tests/integration

sed -i '1{/^#!/d}' rethinkdb/*.py

%build
export LANG=en_US.UTF-8
%pyproject_wheel

%install
export LANG=en_US.UTF-8
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/rethinkdb-repl
%python_clone -a %{buildroot}%{_bindir}/rethinkdb-index-rebuild
%python_clone -a %{buildroot}%{_bindir}/rethinkdb-restore
%python_clone -a %{buildroot}%{_bindir}/rethinkdb-export
%python_clone -a %{buildroot}%{_bindir}/rethinkdb-dump
%python_clone -a %{buildroot}%{_bindir}/rethinkdb-import
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/rethinkdb/rethinkdb-python/issues/168
sed -i 's:from mock:from unittest.mock:' tests/test_*.py
%pytest

%post
%python_install_alternative rethinkdb-repl
%python_install_alternative rethinkdb-index-rebuild
%python_install_alternative rethinkdb-restore
%python_install_alternative rethinkdb-export
%python_install_alternative rethinkdb-dump
%python_install_alternative rethinkdb-import

%postun
%python_uninstall_alternative rethinkdb-repl
%python_uninstall_alternative rethinkdb-index-rebuild
%python_uninstall_alternative rethinkdb-restore
%python_uninstall_alternative rethinkdb-export
%python_uninstall_alternative rethinkdb-dump
%python_uninstall_alternative rethinkdb-import

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/rethinkdb-import
%python_alternative %{_bindir}/rethinkdb-dump
%python_alternative %{_bindir}/rethinkdb-export
%python_alternative %{_bindir}/rethinkdb-restore
%python_alternative %{_bindir}/rethinkdb-index-rebuild
%python_alternative %{_bindir}/rethinkdb-repl
%{python_sitelib}/rethinkdb
%{python_sitelib}/rethinkdb-%{version}.dist-info

%changelog
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- update to 2.4.10.post1:
  * #309 ModuleNotFoundError: No module named 'looseversion'
- update to 2.4.10:
  * #298 Asyncio usage no longer supports Python 3.4
  * Support for Python 3.10-3.12, via
  * #296 Remove loop params that break in Python 3.10
  * #298 Replace asyncio.coroutine attributes with async def
  * #300 Update LooseVersion dependency
  * #303 Specify 'coverage' package version in requirements.txt
  * #267 and #304 Wait for wait_closed (on Python 3.7 and
    greater) in asyncio mode by @dpineiden
  * #308 Make 'restore' command's `-i db.table` option work again
  * #290 Fix bug in stringified query representation logic by
    @liranbg
  * #296 Also, fix warning or error when "is not" is used with an
    empty string
  * We have a new dependency on `looseversion==1.3.0`.
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 2.4.9
  * No breaking change.
  * #276 Fix dump command password reading by @besworks
  * #253 Fix Fix deprecated import collections by @metal3d
* Thu Apr 14 2022 pgajdos@suse.com
- version update to 2.4.8
  * #204 Fix not implemented error by @Inveracity
  * #211 Fix access option.temp_dir correctly in the restore script by @mishawakerman
  * #213 Fix bug in Trio's _read_exactly() by @mehaase
  * #238 Fix Trio Connection Pool Error by @murali-shankar
  * #183 Allowing dash in table namesby @hchac
  * #182 do not close socket on EWOULDBLOCK by @tommilligan
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Mar 19 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.4.5:
  * No upstream changelog.
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Tue Sep 10 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.4.3.post1
